## Introduction
  The FAIR Training Handbook supports trainers to apply the [10 Simple Rules for Making Training Materials Findable, Accessible, Interoperable and Reusable (FAIR)](https://doi.org/10.1371/journal.pcbi.1007854) (Figure 1) [@Garcia2020]. It will explain why FAIR is important and how you can make it happen. Trainers can use the practical suggestions in the following chapters to create or improve their training resources.
  
  <figure>
  <img src="../../assets/images/10SimpleRulesFAIR.png" width="500" alt="Image depicting the 10 Simple Rules for Making Training Materials FAIR. Each rule is associated with a stylised icon. The first rule—to share—is the central starting point; the Findability rules include description, identity, and registration; the latter two, together with access rules, correspond to Accessibility; Interoperability stands on its own, with one rule about formats; the remaining four rules cover different aspects of Reusability."
/>
  
</figure>
  
  Figure 1: Ten simple rules for making training materials FAIR. Reproduced under CC-BY-SA 4.0 from Garcia et al[@Garcia2020].

  
  FAIRifying training materials is an individual journey; it’s important to consider your own unique circumstances, settings and context. As you read through the handbook reflect on how FAIR is FAIR enough for you, and from the outset consider:
  
 *  What training materials do you have?
 *  Who are you FAIRifying them for?
 *  What resourcing, capabilities and capacity do you have? 
 *  Are there institutional or regulatory considerations?

No matter what your setting, there is something you can do to make your training materials FAIRer.

## What are the FAIR Data principles? 
  Before skipping too far ahead, what are the FAIR Data Principles? The FAIR data principles were published in 2016 [@PMID:26978244]; FAIR stands for - F for Findable, A for Accessible, I for interoperable, R for Reusable. The FAIR Data Principles make data more valuable as it is easier to find through unique identifiers and easier to combine and integrate thanks to the formal shared knowledge representation. It’s important to note that the FAIR Data Principles were created to be understood/applied not only by humans but also by machines, in an automated way.

More broadly, the FAIR principles describe how research outputs should be organised so they can be more easily accessed, understood, exchanged and reused. The FAIR principles describe a continuum of increasing reusability.
How can we translate the FAIR principles to training materials?
Preparing training materials is time-consuming and challenging for both new and experienced trainers. Reusing existing materials is a possible solution but it requires that materials have been shared, properly described, and made available (i.e licenced) for reuse by their authors. 

The bioinformatics training community set out to address these challenges by adapting the FAIR Data Principles to training materials. The result of this community exercise was 10 Simple Rules for Making Training Materials FAIR (Figure 1) [@Garcia2020]. This handbook expands on these rules by providing extra guidance and advice on the process of making your training materials FAIR.

!!! Note "FAIR and Open"
    Did you know that ‘FAIR’ is not the same as ‘Open’? The FAIR Data motto makes this difference quite clear: “as open as possible, as closed as necessary”. Read more in [Chapter 1](https://elixir-fair-training.github.io/FAIR-training-handbook/chapters/chapter_01/).

## Training materials - what’s in scope?
What is a training material and what types of training materials should you consider making FAIR? A simple definition of training material is anything you would produce yourself (or reuse) as a support for your teaching activity. These can be slides, datasets, videos, software, a GitHub repo, a collection of exercises, Virtual Machines (VMs)/Containers, etc. In summary, any digital object that can be used to deliver a lesson, course, curriculum, etc. For more information, please read [Chapter 2](https://elixir-fair-training.github.io/FAIR-training-handbook/chapters/chapter_02/) and [Chapter 3](https://elixir-fair-training.github.io/FAIR-training-handbook/chapters/chapter_03/).

## What’s Next?
Read the following chapters to discover options for implementing FAIR with your training materials. Your path through this handbook needn’t be linear; jump around the chapters and dip into the ones that are most relevant to you.

Consider your own setting and why FAIR is important to you. How FAIR is FAIR enough? That is up to you. Remember that FAIR is a journey and perfection is the enemy of good - FAIRer training materials are better than materials that are not FAIR at all.

Happy travels!

