---
tags:
    - Communication
    - Discoverability
    - Public relations
    - Training portals
    - Registries
    - Repositories
    - Social media

---
!!! Checklist  

    9.1 Add or link your materials in training registries (eg TeSS), collections of materials (Glittr, GOBLET), etc.
    
    9.2 Communicate and share this information with the world through: social media, mailing lists, blogs, conferences, your own channels, etc.


## Description

This chapter explains how to let learners, other trainers, and anyone interested in the topic of your training materials discover them, i.e., public relations. We will provide examples of platforms you can use to communicate and let the world know about your materials.

!!! info "Learning outcomes"
    **At the end of this chapter you should be able to:**

    1. List the communication channels where you can share training materials
    2. Explain the benefits of registering your materials on a public site
    3. Identify the online registry(ies)  that is(are) appropriate for your materials

## Where to share your materials

You have finished putting together your training materials and are ready to share them with the community. How should you go about this? What channels of communication can you use?
Public relations (PR) is the practice of managing and disseminating information from an individual or an organization to the public in order to influence their perception. This generally involves putting out the information that your materials are available using different channels. You may want to consider the following platforms to boost discoverability:

 1. Registries
 2. Repositories
 3. Social media
 4. Blogs
 5. Congresses or other events

As each approach reaches out to a different public, you may choose to use several channels to communicate.

## Training registries

A training registry or portal aggregates information, i.e. the metadata (see [Chapter 4: Using metadata to describe training material](chapter_04.md)), about many different training materials. Registries do not contain the training materials, they link to the materials.  As registries centralize the information, they are one of the first go-to places learners or trainers will explore when looking for material. Let’s consider a few well-known training registries:

### TESS

The ELIXIR Training e-Support System (TeSS) [@TeSS-materials] integrates information about training materials from Europe and beyond since 2015. TeSS offers an easy-to-use interface, including faceted filtering and search features to help users browse and discover training information. 

You can register your training materials in TeSS manually. This requires a login but involves consistent significant effort to ensure that information is registered in a timely manner and updated regularly.

Consequently, TeSS’ primary mechanism for acquiring training metadata is to aggregate from content providers automatically. Bespoke scrapers are run daily to extract information from a range of target websites to collect different training materials. If you are planning to register training materials for numerous courses, you should consider this approach.

### GOBLET

The Global Organization for Bioinformatics Learning, Education and Training (GOBLET) training portal [@GOBLET-materials] spans the fields of bioinformatics, biocuration, biocomputing and computational biology. Training materials are available under a CC BY-SA 3.0 license (see [Chapter 8: Licensing](chapter_08.md)) for download and use. 

You can upload your materials manually provided you are a registered member. If that’s not the case, contact a GOBLET-affiliated trainer who will be able to do this for you.

!!! note
    Does your institution have a web page listing all the courses? If so, include a link to your materials in your course entry so that students and other trainers know where to find them

## Online repositories

If you are using platforms such as Zenodo, GitHub and GitLab (see [Chapter 3: Getting readty to create your materials or reuse](chapter_03.md))) in the development of your training materials, you are already making them accessible to the community. All a trainee or trainer needs to do is search for a topic and, if your materials are properly indexed, they will be able to view them and download them depending on the access right (see [Chapter 6: Make it accessible](chapter_06.md)).

!!! note
     A training repository (or repo) is a central location in which training materials are stored and managed. Online repositories are thus used to deposit your training materials and share them with the community.

## Social media

Social media can be an important way to promote your training material to the wider community and make them more discoverable. This can be a very effective strategy when the account posting the information is well-known and has a large following. Social media require an account; if you don’t have an account or do not want to spend time on social media, consider contacting your institutional communication team to see if they can advertise your training materials.

Below are some of the social media channels that you may wish to use to promote your training material:

 1. **Twitter.** A post (tweet) on Twitter is a short text which may also feature images or links to websites and resources. By including the handles (these start with @) of your co-authors, institute, funders, you will acknowledge them in the announcement. If you are presenting your course materials at a congress or event, consider using the event hashtag (theses start with #), you will ensure that everyone who is following the event on Twitter will be reached. It is an ideal medium to announce to the world that your materials are available, from where, updates, etc.
 2. **Facebook.** Posts on Facebook are similar to posts on Twitter, except that there are no constraints on the length of the text. By joining groups focussing on training or on the topic covered by your training material, your posts will be directed to an audience sharing an interest in training.
 3. **LinkedIn.** There are two ways to make your training materials discoverable on LinkedIn: (1) You can include links to your training material when you create your profile, as part of the summary of your professional expertise and accomplishments, or on your feed. (2) Posts in LinkedIn are similar to posts on Facebook, except that this is a channel mostly used for professional purposes. By joining groups focusing on training in Linkedin, your posts will attract the attention of the training community. If you decide to post such that anyone can view your post, your network will be notified and anyone looking up the topic will be able to view your post.
 4. **Instagram.** Instagram provides an opportunity to create interest in your training material through visuals. Infographics, short videos, or visual storytelling of the research journey can be shared on this platform. Link to your content materials in your bio, to catch the interest of students.
 5. **YouTube.** Students are using videos as an easy way to start exploring a topic. If you already have video content relating to your training material, consider uploading them to YouTube to promote your training material.

## Blogs

A blog is a regularly updated website or web page, typically one run by an individual or small group, written in an informal or conversational style. Blogging is an effective way to reach new audiences and increase the discoverability of your training material. 

## Congresses or other events

All the channels mentioned so far are digital communication channels. Try not to restrict yourself to such channels, but take advantage of face-to-face events to present your course materials. This may take many different forms: Posters, presentations, workshops, tutorials, all represent ways to reach out to students or the training community.

## Resources and References

\bibliography


